@@ -1,4 +1,4 @@
-# $Id: Metamark.pm,v 1.89 2004/10/30 12:52:01 dave Exp $
+# $Id: Metamark.pm,v 1.90 2005/09/03 15:23:57 dave Exp $
 
 =head1 NAME
 
@@ -29,7 +29,7 @@ use warnings;
 
 use base qw( WWW::Shorten::generic Exporter );
 our @EXPORT = qw(makeashorterlink makealongerlink);
-our $VERSION = sprintf "%d.%02d", '$Revision: 1.89 $ ' =~ /(\d+)\.(\d+)/;
+our $VERSION = sprintf "%d.%02d", '$Revision: 1.90 $ ' =~ /(\d+)\.(\d+)/;
 
 use Carp;
 
@@ -71,21 +71,13 @@ sub makealongerlink ($)
 	or croak 'No Metamark key / URL passed to makealongerlink';
     my $ua = __PACKAGE__->ua();
 
-    $short_url =~ s{ ^\Qhttp://xrl.us/\E }{}x;
-    $short_url = "http://xrl.us/$short_url" unless $short_url =~ m!^http://!i;
-    $ua->cookie_jar({});
-    $ua->cookie_jar->set_cookie(
-	0,
-	z => '1/rc/1/q/5Phox2UBRVHMAAA-hCdUCC5D4A89/lr/1041904089/600E9895',
-	'/' => 'xrl.us',
-	undef, 1, 0, 2400,0 
-    );
-
-    my $resp = $ua->get($short_url);
-    return undef unless $resp->is_redirect;
-    my $url = $resp->header('Location');
-    return $url;
-
+    my $resp  = $ua->post( 'http://metamark.net/api/rest/simple', [
+        short_url => $short_url,
+    ] );
+    return unless $resp->is_success;
+    return if $resp->content =~ /^ERROR:/;
+    # I love REST. It's so simple when done properly.
+    return $resp->content;
 }
 
 1;
